@@ -39,7 +39,7 @@ class Dataset(BaseResource):
             timestamp_column=timestamp_column,
             group_by_column=group_by_column,
             order_by_column=order_by_column,
-            group_order_sort=SortOrder(group_order_sort),
+            group_order_sort=SortOrder(group_order_sort) if group_order_sort is not None else None,
             raw_inputs=[
                 FieldSchema(name=name, type=FieldType(type)) for name, type in raw_inputs.items()
             ]
