@@ -56,7 +56,7 @@ class Segment(BaseResource):
         elif any(
             [
                 self._args.get("terms") != resource_data["terms_values"],
-                self._args.get("field_name") != (resource_data["field"] or {}).get("name"),
+                self._args.get("field_name") != resource_field_name,
                 values != resource_data["values"],
             ]
         ):
