@@ -303,8 +303,8 @@ class Stack:
             code = f"""{self.__resource_name_to_python_name(resource.name)} = aporia.Segment(
     "{resource.name}",
 """
-            if resource.raw_data["field"] is not None:
-                code += f"""\tfield="{resource.raw_data["field"]["name"]}",\n"""
+            if resource.raw_data["field_name"] is not None:
+                code += f"""\tfield="{resource.raw_data["field_name"]}",\n"""
                 code += f"""\tvalues={resource.raw_data["values"]}\n"""
             else:
                 code += f"""\tterms={resource.raw_data["terms_values"]}\t"""
@@ -712,7 +712,7 @@ def add_model(stack: aporia.Stack):
 
         return resources, model_code, model_name
 
-    def _import(self, output_directory: str):
+    def _import(self, output_directory: str, model_names: Optional[List[str]]):
         # data_sources = self._aporia_api.get_data_sources()
         models = self._aporia_api.get_models()
         resources = OrderedDict()
@@ -722,6 +722,8 @@ def add_model(stack: aporia.Stack):
         models_code = {}
 
         for index, model in enumerate(models):
+            if model_names is not None and model.name not in model_names:
+                continue
             model_resources, model_code, model_name = self.__iterate_model(model=model, index=index)
             for name, data in model_resources.items():
                 if name in resources.keys():
