@@ -16,7 +16,7 @@ class Segment(BaseAporiaResource):
         self.name = data["name"]
         self.field_name = data["field_name"]
         self.values = data["values"]
-        self.term = data["term"]
+        self.terms = data["terms_values"]
 
     @classmethod
     def get_all(
@@ -74,7 +74,7 @@ class Segment(BaseAporiaResource):
         name: Optional[str] = None,
         # field_name: Optional[str] = None,
         values: Optional[Union[List[str], List[Union[float, int]]]] = None,
-        term: Optional[str] = None,
+        terms: Optional[List[Tuple[str, str]]] = None,
         **kwargs,
     ):
         args = {}
@@ -84,13 +84,12 @@ class Segment(BaseAporiaResource):
         #     args["field_name"] = field_name
         if values is not None:
             args["values"] = values
-        if term is not None:
-            args["term"] = term
+        if terms is not None:
+            args["terms_values"] = terms
         response = self.client.send_request(
             f"/data-segments/{self.id}",
-            "POST",
+            "PUT",
             args,
-            url_search_replace=("/api/v1/", "/v1/crud-service/"),
         )
         # response = self.client.send_request(f"/data-segments/{self.id}", "PUT", args)
         self.client.assert_response(response)
